@@ -137,6 +137,8 @@ class AlephAPI(object):
             publisher_url = collection_.get('links', {}).get('ui')
             publisher_url = collection_.get('publisher_url', publisher_url)
             prop_push(properties, 'publisherUrl', publisher_url)
+
+        entity['properties'] = properties
         return entity
 
     def _request(self, method: str, url: str, **kwargs) -> Dict:
@@ -176,6 +178,34 @@ class AlephAPI(object):
         url = self._make_url(f'collections/{collection_id}')
         return self._request('GET', url)
 
+    def reingest_collection(self, collection_id: str,
+                            index: bool = False):
+        """Re-ingest all documents in a collection."""
+        url = self._make_url(f"collections/{collection_id}/reingest",
+                             index=index)
+        return self._request("POST", url)
+
+    def reindex_collection(self, collection_id: str,
+                           flush: bool = False,
+                           sync: bool = False):
+        """Re-index all entities in a collection."""
+        url = self._make_url(f"collections/{collection_id}/reindex",
+                             sync=sync, flush=flush)
+        return self._request("POST", url)
+
+    def delete_collection(self, collection_id: str,
+                          sync: bool = False):
+        """Delete a collection by ID"""
+        url = self._make_url(f"collections/{collection_id}", sync=sync)
+        return self._request("DELETE", url)
+
+    def flush_collection(self, collection_id: str,
+                         sync: bool = False):
+        """Empty all contents from a collection by ID"""
+        url = self._make_url(f"collections/{collection_id}", sync=sync,
+                             keep_metadata=True)
+        return self._request("DELETE", url)
+
     def get_entity(self, entity_id: str, publisher: bool = False) -> Dict:
         """Get a single entity by ID."""
         url = self._make_url(f'entities/{entity_id}')
@@ -192,8 +222,10 @@ class AlephAPI(object):
         return None
 
     def load_collection_by_foreign_id(self, foreign_id: str,
-                                      config: Optional[Dict] = None) -> Dict:
-        """Get a collection by its foreign ID, or create one."""
+                                      config: Optional[Dict] = None
+                                      ) -> Dict:
+        """Get a collection by its foreign ID, or create one. Setting clear
+        will clear any found collection."""
         collection = self.get_collection_by_foreign_id(foreign_id)
         if collection is not None:
             return collection
@@ -236,7 +268,8 @@ class AlephAPI(object):
         url = self._make_url("collections")
         return self._request("POST", url, json=data)
 
-    def update_collection(self, collection_id: str, data: Dict) -> Dict:
+    def update_collection(self, collection_id: str, data: Dict,
+                          sync: bool = False) -> Dict:
         """Update an existing collection using the given data.
 
         params
@@ -245,20 +278,9 @@ class AlephAPI(object):
         data: dict with foreign_id, label, category etc. See `CollectionSchema`
         for more details.
         """
-        url = self._make_url(f"collections/{collection_id}")
+        url = self._make_url(f"collections/{collection_id}", sync=sync)
         return self._request("PUT", url, json=data)
 
-    def map_collection(self, collection_id: str, mapping: Dict):
-        """Run a bulk entity data mapping on a collection.
-
-        params
-        ------
-        collection_id: id of the collection to update
-        mapping: dict with the entity bulk load mapping.
-        """
-        url = self._make_url(f"collections/{collection_id}/mapping")
-        return self._request("PUT", url, json=mapping)
-
     def stream_entities(self, collection: Optional[Dict] = None,
                         include: Optional[List] = None,
                         schema: Optional[str] = None,
@@ -317,6 +339,8 @@ class AlephAPI(object):
         """
         chunk = []
         for entity in entities:
+            if hasattr(entity, 'to_dict'):
+                entity = entity.to_dict()
             chunk.append(entity)
             if len(chunk) >= chunk_size:
                 self._bulk_chunk(collection_id, chunk, **kw)
@@ -347,7 +371,9 @@ class AlephAPI(object):
 
     def ingest_upload(self, collection_id: str,
                       file_path: Optional[Path] = None,
-                      metadata: Optional[Dict] = None) -> Dict:
+                      metadata: Optional[Dict] = None,
+                      sync: bool = False,
+                      index: bool = True) -> Dict:
         """
         Create an empty folder in a collection or upload a document to it
 
@@ -360,7 +386,8 @@ class AlephAPI(object):
         directory contains foreign_id for itself as well as its parent and the
         name of the directory.
         """
-        url = self._make_url("collections/{0}/ingest".format(collection_id))
+        url_path = "collections/{0}/ingest".format(collection_id)
+        url = self._make_url(url_path, sync=sync, index=index)
         if not file_path or file_path.is_dir():
             data = {"meta": json.dumps(metadata)}
             return self._request("POST", url, data=data)
